@@ -1,8 +1,8 @@
 
-from .docker import Docker
 from .http import RealResponse, StubResponse, Request
 from .package import Package
 from .platform import Platform
 from .shell import Shell
+from .statsd import StatsdMock
 
-__all__ = ['Shell', 'Docker', 'Package', 'Platform', 'RealResponse', 'StubResponse', 'Request']
\ No newline at end of file
+__all__ = ['Shell', 'Package', 'Platform', 'RealResponse', 'StubResponse', 'Request', 'StatsdMock']
\ No newline at end of file
